Documentation
¶
Index ¶
- Constants
- type Options
- type S3
- func (s *S3) Export(ctx context.Context, prefix, filename string, r io.Reader) (newFilename string, err error)
- func (s *S3) Get(ctx context.Context, prefix, filename string, fn func(r io.Reader) error) (err error)
- func (s *S3) GetInfo(ctx context.Context, prefix, filename string) (info kiroku.Info, err error)
- func (s *S3) GetNext(ctx context.Context, prefix, lastFilename string) (nextKey string, err error)
- func (s *S3) GetNextList(ctx context.Context, prefix, lastFilename string, maxkeys int64) (nextKeys []string, err error)
- func (s *S3) Import(ctx context.Context, prefix, filename string, w io.Writer) (err error)
Constants ¶
const ( // ErrInvalidName is returned when a name is empty ErrInvalidName = errors.Error("invalid name, cannot be empty") // ErrInvalidDirectory is returned when a directory is empty ErrInvalidDirectory = errors.Error("invalid directory, cannot be empty") )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
Key string `toml:"key" json:"key"`
Secret string `toml:"secret" json:"secret"`
Endpoint string `toml:"endpoint" json:"endpoint"`
Region string `toml:"region" json:"region"`
Bucket string `toml:"bucket" json:"bucket"`
AvoidBucketCreation bool `toml:"avoid-bucket-creation" json:"avoidBucketCreation"`
MaxRatePerSecond int64 `toml:"max-rate-per-second" json:"maxRatePerSecond"`
}
Click to show internal directories.
Click to hide internal directories.